cloud_inquisitor\.plugins\.notifiers\.slack
-------------------------------------------

.. automodule:: cloud_inquisitor.plugins.notifiers.slack
    :members:
    :no-undoc-members:
    :show-inheritance:
